searchData={"items":[{"type":"module","title":"Split","doc":"The Split.io Elixir thin client.\n\nThis module provides a simple API to interact with the Split.io service\nvia the [Split Daemon (splitd)](https://help.split.io/hc/en-us/articles/18305269686157-Split-Daemon-splitd).","ref":"Split.html"},{"type":"module","title":"Adding Split to Your Supervision Tree - Split","doc":"The most basic approach is to add `Split` as a child of your application's\ntop-most supervisor, i.e. `lib/my_app/application.ex`.\n\n    defmodule MyApp.Application do\n      use Application\n\n      def start(_type, _args) do\n        children = [\n          # ... other children ...\n          {Split, [socket_path: \"/var/run/split.sock\"]}\n        ]\n\n        opts = [strategy: :one_for_one, name: MyApp.Supervisor]\n        Supervisor.start_link(children, opts)\n      end\n    end\n\nYou can also start `Split` dynamically by calling `Split.Supervisor.start_link/1`:\n\n    Split.Supervisor.start_link(opts)","ref":"Split.html#module-adding-split-to-your-supervision-tree"},{"type":"module","title":"Options - Split","doc":"`Split` takes a number of keyword arguments as options when starting. The following options are available:\n\n- `:socket_path`: **OPTIONAL** The path to the splitd socket file. Default is `\"/var/run/splitd.sock\"`.\n- `:pool_size`: **OPTIONAL** The size of the pool of connections to the splitd daemon. Default is the number of online schedulers in the Erlang VM (See: https://www.erlang.org/doc/apps/erts/erl_cmd.html).\n- `:connect_timeout`: **OPTIONAL** The timeout in milliseconds to connect to the splitd daemon. Default is `1000`.","ref":"Split.html#module-options"},{"type":"module","title":"Using the API - Split","doc":"Once you have started Split, you are ready to start interacting with the Split.io splitd's daemon to access feature flags and configurations.\n\n    Split.get_treatment(\"user_key\", \"feature_name\")","ref":"Split.html#module-using-the-api"},{"type":"function","title":"Split.child_spec/1","doc":"Builds a child specification to use in a Supervisor.\n\nNormally not called directly by your code. Instead, it will be\ncalled by your application's Supervisor once you add `Split`\nto its supervision tree.","ref":"Split.html#child_spec/1"},{"type":"function","title":"Split.get_treatment/3","doc":"Gets the treatment string for a given key, feature flag name and optional attributes.","ref":"Split.html#get_treatment/3"},{"type":"function","title":"Examples - Split.get_treatment/3","doc":"iex> Split.get_treatment(\"user_id\", \"located_in_usa\")\n    \"off\"\n    iex> Split.get_treatment(\"user_id\", \"located_in_usa\", %{country: \"USA\"})\n    \"on\"","ref":"Split.html#get_treatment/3-examples"},{"type":"function","title":"Split.get_treatment_with_config/3","doc":"Gets the treatment with config for a given key, feature flag name and optional attributes.","ref":"Split.html#get_treatment_with_config/3"},{"type":"function","title":"Examples - Split.get_treatment_with_config/3","doc":"iex> Split.get_treatment_with_config(\"user_id\", \"located_in_usa\")\n    %Split.TreatmentWithConfig{treatment: \"off\", config: nil}\n    iex> Split.get_treatment(\"user_id\", \"located_in_usa\", %{country: \"USA\"})\n    %Split.TreatmentWithConfig{treatment: \"on\", config: nil}","ref":"Split.html#get_treatment_with_config/3-examples"},{"type":"function","title":"Split.get_treatments/3","doc":"Gets a map of feature flag names to treatments for a given key, list of feature flag names and optional attributes.","ref":"Split.html#get_treatments/3"},{"type":"function","title":"Examples - Split.get_treatments/3","doc":"iex> Split.get_treatments(\"user_id\", [\"located_in_usa\"])\n    %{\"located_in_usa\" => \"off\"}\n    iex> Split.get_treatments(\"user_id\", [\"located_in_usa\"], %{country: \"USA\"})\n    %{\"located_in_usa\" => \"on\"}","ref":"Split.html#get_treatments/3-examples"},{"type":"function","title":"Split.get_treatments_by_flag_set/3","doc":"Gets a map of feature flag names to treatment strings for a given key, flag set name and optional attributes.","ref":"Split.html#get_treatments_by_flag_set/3"},{"type":"function","title":"Examples - Split.get_treatments_by_flag_set/3","doc":"iex> Split.get_treatments_by_flag_set(\"user_id\", \"frontend_flags\")\n    %{\"located_in_usa\" => \"off\"}\n    iex> Split.get_treatments_by_flag_set(\"user_id\", \"frontend_flags\", %{country: \"USA\"})\n    %{\"located_in_usa\" => \"on\"}","ref":"Split.html#get_treatments_by_flag_set/3-examples"},{"type":"function","title":"Split.get_treatments_by_flag_sets/3","doc":"Gets a map of feature flag names to treatment strings for a given key, flag set name and optional attributes.","ref":"Split.html#get_treatments_by_flag_sets/3"},{"type":"function","title":"Examples - Split.get_treatments_by_flag_sets/3","doc":"iex> Split.get_treatments_by_flag_sets(\"user_id\", [\"frontend_flags\", \"backend_flags\"])\n    %{\"located_in_usa\" => \"off\"}\n    iex> Split.get_treatments_by_flag_sets(\"user_id\", [\"frontend_flags\", \"backend_flags\"], %{country: \"USA\"})\n    %{\"located_in_usa\" => \"on\"}","ref":"Split.html#get_treatments_by_flag_sets/3-examples"},{"type":"function","title":"Split.get_treatments_with_config/3","doc":"Gets a map of feature flag names to treatments with config for a given key, list of feature flag names and optional attributes.","ref":"Split.html#get_treatments_with_config/3"},{"type":"function","title":"Examples - Split.get_treatments_with_config/3","doc":"iex> Split.get_treatments_with_config(\"user_id\", [\"located_in_usa\"])\n    %{\"located_in_usa\" => %Split.TreatmentWithConfig{treatment: \"off\", config: nil}}\n    iex> Split.get_treatments_with_config(\"user_id\", [\"located_in_usa\"], %{country: \"USA\"})\n    %{\"located_in_usa\" => %Split.TreatmentWithConfig{treatment: \"on\", config: nil}}","ref":"Split.html#get_treatments_with_config/3-examples"},{"type":"function","title":"Split.get_treatments_with_config_by_flag_set/3","doc":"Gets a map of feature flag names to treatments with config for a given key, flag set name and optional attributes.","ref":"Split.html#get_treatments_with_config_by_flag_set/3"},{"type":"function","title":"Examples - Split.get_treatments_with_config_by_flag_set/3","doc":"iex> Split.get_treatments_with_config_by_flag_set(\"user_id\", \"frontend_flags\")\n    %{\"located_in_usa\" => %Split.TreatmentWithConfig{treatment: \"off\", config: nil}}\n    iex> Split.get_treatments_with_config_by_flag_set(\"user_id\", \"frontend_flags\", %{country: \"USA\"})\n    %{\"located_in_usa\" => %Split.TreatmentWithConfig{treatment: \"on\", config: nil}}","ref":"Split.html#get_treatments_with_config_by_flag_set/3-examples"},{"type":"function","title":"Split.get_treatments_with_config_by_flag_sets/3","doc":"Gets a map of feature flag names to treatments with config for a given key, flag set name and optional attributes.","ref":"Split.html#get_treatments_with_config_by_flag_sets/3"},{"type":"function","title":"Examples - Split.get_treatments_with_config_by_flag_sets/3","doc":"iex> Split.get_treatments_with_config_by_flag_sets(\"user_id\", [\"frontend_flags\", \"backend_flags\"])\n    %{\"located_in_usa\" => %Split.TreatmentWithConfig{treatment: \"off\", config: nil}}\n    iex> Split.get_treatments_with_config_by_flag_sets(\"user_id\", [\"frontend_flags\", \"backend_flags\"], %{country: \"USA\"})\n    %{\"located_in_usa\" => %Split.TreatmentWithConfig{treatment: \"on\", config: nil}}","ref":"Split.html#get_treatments_with_config_by_flag_sets/3-examples"},{"type":"function","title":"Split.split/1","doc":"Gets the data of a given feature flag name in `SplitView` format.","ref":"Split.html#split/1"},{"type":"function","title":"Examples - Split.split/1","doc":"iex> Split.split(\"located_in_usa\")\n    %Split.SplitView{\n      name: \"located_in_usa\",\n      traffic_type: \"user\",\n      killed: false,\n      treatments: [\"on\", \"off\"],\n      change_number: 123456,\n      configs: %{ \"on\" => nil, \"off\" => nil },\n      default_treatment: \"off\",\n      sets: [\"frontend_flags\"],\n      impressions_disabled: false\n    }","ref":"Split.html#split/1-examples"},{"type":"function","title":"Split.split_names/0","doc":"Gets the list of all feature flag names.","ref":"Split.html#split_names/0"},{"type":"function","title":"Examples - Split.split_names/0","doc":"iex> Split.split_names()\n    [\"located_in_usa\"]","ref":"Split.html#split_names/0-examples"},{"type":"function","title":"Split.splits/0","doc":"Gets the data of all feature flags in `SplitView` format.","ref":"Split.html#splits/0"},{"type":"function","title":"Examples - Split.splits/0","doc":"iex> Split.splits()\n    [%Split.SplitView{\n      name: \"located_in_usa\",\n      traffic_type: \"user\",\n      killed: false,\n      treatments: [\"on\", \"off\"],\n      change_number: 123456,\n      configs: %{ \"on\" => nil, \"off\" => nil },\n      default_treatment: \"off\",\n      sets: [\"frontend_flags\"],\n      impressions_disabled: false\n    }]","ref":"Split.html#splits/0-examples"},{"type":"function","title":"Split.track/5","doc":"Tracks an event for a given key, traffic type, event type, and optional numeric value and map of properties.\nReturns `true` if the event was successfully tracked, or `false` otherwise, e.g. if the Split daemon is not running or cannot be reached.\n\nSee: https://help.split.io/hc/en-us/articles/26988707417869-Elixir-Thin-Client-SDK#track","ref":"Split.html#track/5"},{"type":"function","title":"Examples - Split.track/5","doc":"iex> Split.track(\"user_id\", \"user\", \"my-event\")\n    true\n    iex> Split.track(\"user_id\", \"user\", \"my-event\", 42)\n    true\n    iex> Split.track(\"user_id\", \"user\", \"my-event\", nil, %{property1: \"value1\"})\n    true\n    iex> Split.track(\"user_id\", \"user\", \"my-event\", 42, %{property1: \"value1\"})\n    true","ref":"Split.html#track/5-examples"},{"type":"type","title":"Split.attributes/0","doc":"A map of attributes to use when evaluating feature flags.","ref":"Split.html#t:attributes/0"},{"type":"type","title":"Split.option/0","doc":"An option that can be provided when starting `Split`. See [options](#module-options) for more information.","ref":"Split.html#t:option/0"},{"type":"type","title":"Split.options/0","doc":"Options to start the `Split` application.","ref":"Split.html#t:options/0"},{"type":"type","title":"Split.properties/0","doc":"A map of properties to use when tracking an event.","ref":"Split.html#t:properties/0"},{"type":"type","title":"Split.split_key/0","doc":"The [traffic type identifier](https://help.split.io/hc/en-us/articles/360019916311-Traffic-types).\nIt can be either a string or a map with a matching key and an optional bucketing key.","ref":"Split.html#t:split_key/0"},{"type":"module","title":"Split.SplitView","doc":"This module defines a struct that contains information about a feature flag.","ref":"Split.SplitView.html"},{"type":"module","title":"Fields - Split.SplitView","doc":"* `:name` - The name of the feature flag\n  * `:traffic_type` - The traffic type of the feature flag\n  * `:killed` - A boolean that indicates if the feature flag is killed\n  * `:treatments` - The list of treatments of the feature flag\n  * `:change_number` - The change number of the feature flag\n  * `:configs` - The map of treatments and their configurations\n  * `:default_treatment` - The default treatment of the feature flag\n  * `:sets` - The list of flag sets that the feature flag belongs to\n  * `:impressions_disabled` - A boolean that indicates if the tracking of impressions is disabled","ref":"Split.SplitView.html#module-fields"},{"type":"type","title":"Split.SplitView.t/0","doc":"","ref":"Split.SplitView.html#t:t/0"},{"type":"module","title":"Split.Supervisor","doc":"The supervisor for the Split SDK.","ref":"Split.Supervisor.html"},{"type":"function","title":"Split.Supervisor.child_spec/1","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"Split.Supervisor.html#child_spec/1"},{"type":"function","title":"Split.Supervisor.init/1","doc":"","ref":"Split.Supervisor.html#init/1"},{"type":"function","title":"Split.Supervisor.start_link/1","doc":"","ref":"Split.Supervisor.html#start_link/1"},{"type":"module","title":"Split.TreatmentWithConfig","doc":"This module is a struct that represents a treatment with a configuration.","ref":"Split.TreatmentWithConfig.html"},{"type":"module","title":"Fields - Split.TreatmentWithConfig","doc":"* `:treatment` - The treatment string value\n  * `:config` - The treatment configuration string or nil if the treatment has no configuration","ref":"Split.TreatmentWithConfig.html#module-fields"},{"type":"type","title":"Split.TreatmentWithConfig.t/0","doc":"","ref":"Split.TreatmentWithConfig.html#t:t/0"}],"content_type":"text/markdown","producer":{"name":"ex_doc","version":[48,46,51,52,46,50]}}